package logging

import (
	"fmt"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
)

func Test_LevelByName(t *testing.T) {
	t.Parallel()

	for _, levelName := range levelNames {
		l, e := LevelByName(levelName)
		if e != nil {
			t.Errorf("level %s not recognized", levelName)
		}

		if l.Name() != levelName {
			t.Errorf("expected '%s', got '%s'", levelName, l.Name())
		}
	}
}

func Test_defaultFormatter(t *testing.T) {
	t.Parallel()

	r := &Record{
		Timestamp: time.Date(2000, 0o1, 0o2, 0o3, 0o4, 0o5, 123456789, time.Local),
		Level:     Info,
		Logger:    "my logger",
		Message:   "my log line",
	}

	got := defaultFormatter(r)
	want := fmt.Sprintf("2000/01/02 03:04:05.123456 [INFO    ] my logger: my log line\n")

	assert.Equal(t, want, got)
}
